import React, { useState, useEffect } from 'react';

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
    return;
  }

  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance");
}

var getAvatarList =
/*#__PURE__*/
function () {
  var _ref2 = _asyncToGenerator(
  /*#__PURE__*/
  regeneratorRuntime.mark(function _callee(_ref) {
    var fileName, repo, owner, url, data;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            fileName = _ref.fileName, repo = _ref.repo, owner = _ref.owner;
            url = "https://github-contributors-list.azurewebsites.net/api/getAvatarList?code=GPhCUq8TpjewUtWN4SK1bo71AfEtOw8utSjqaqbFcmWB1sThCKfsHQ==&filename=".concat(fileName, "&owner=").concat(owner, "&repo=").concat(repo);
            _context.next = 4;
            return fetch(url, {
              mode: 'cors'
            }).then(function (res) {
              return res.json();
            }).catch(function (e) {
              return console.log(e);
            });

          case 4:
            data = _context.sent;

            if (data) {
              _context.next = 7;
              break;
            }

            return _context.abrupt("return", []);

          case 7:
            return _context.abrupt("return", data);

          case 8:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function getAvatarList(_x) {
    return _ref2.apply(this, arguments);
  };
}();

var AvatarList = function AvatarList(_ref3) {
  var className = _ref3.className,
      renderItem = _ref3.renderItem,
      repo = _ref3.repo,
      owner = _ref3.owner,
      style = _ref3.style,
      fileName = _ref3.fileName;

  var _useState = useState([]),
      _useState2 = _slicedToArray(_useState, 2),
      list = _useState2[0],
      setList = _useState2[1];

  var _useState3 = useState(true),
      _useState4 = _slicedToArray(_useState3, 2),
      loading = _useState4[0],
      setLoading = _useState4[1];

  useEffect(function () {
    getAvatarList({
      owner: owner,
      repo: repo,
      fileName: fileName
    }).then(function (data) {
      setList(data);
      setLoading(false);
    }).catch(function () {
      setLoading(false);
    });
  }, []);

  if (loading) {
    return React.createElement("div", null, renderItem && renderItem({}, true) || React.createElement("span", null, "loading"));
  }

  return React.createElement(React.Fragment, null, React.createElement("ul", {
    className: className,
    style: _objectSpread2({
      display: 'flex',
      listStyle: 'none',
      margin: 0,
      padding: 0
    }, style)
  }, list.map(function (item) {
    if (renderItem) {
      return renderItem(item, loading);
    }

    return React.createElement("li", {
      style: {
        marginRight: 8,
        borderRadius: 20,
        overflow: 'hidden',
        border: '1px solid #ddd'
      }
    }, React.createElement("a", {
      href: "https://github.com/".concat(item.username)
    }, React.createElement("img", {
      width: 40,
      src: item.url,
      alt: item.username
    })));
  })));
};

export default AvatarList;
